@@ -215,7 +215,9 @@ def write_l1_task(complete_common_header, request):
     ) as task:
         num_of_stokes_params = request.param
         stokes_params = ["I", "Q", "U", "V"]
-        hdu = fits.PrimaryHDU(data=np.ones(shape=(128, 128)), header=complete_common_header)
+        hdu = fits.PrimaryHDU(
+            data=np.random.random(size=(1, 128, 128)) * 10, header=complete_common_header
+        )
         logging.info(f"{num_of_stokes_params=}")
         hdul = fits.HDUList([hdu])
         for i in range(num_of_stokes_params):
@@ -295,7 +297,7 @@ def make_movie_frames_task(tmp_path, recipe_run_id):
 
 def test_make_movie_frames_task(make_movie_frames_task, mocker):
     """
-    :Given: an make_movie_frames_task task
+    :Given: a make_movie_frames_task task
     :When: running the task
     :Then: no errors are raised and a movie file is created
     """
